package de.bsvrz.sys.usv.enums;

/**
 * Zuordnung der Zustände des Attributs KritischerZustand der Attributgruppe
 * USV-kritischer Zustand
 * 
 * @author ObertM
 * @author Christian Hösel, BitCtrl Systems GmbH
 * 
 */
public enum KritischerZustand {

	/**
	 * Der {@link KritischerZustand} "Nicht ermittelbar" (-1).
	 */
	na("nicht ermittelbar", -1),

	/**
	 * Der {@link KritischerZustand} "noch nicht erreicht" (0).
	 */
	normal("noch nicht erreicht", 0),

	/**
	 * Der {@link KritischerZustand} "erreicht" (1).
	 */
	kritisch("erreicht", 1);

	private final String m_text;
	private final int m_value;

	/**
	 * Privater Konstruktor zur Erzeugung eines {@link KritischerZustand}.
	 * 
	 * @param text
	 *            der Name des {@link KritischerZustand}.
	 * @param value
	 *            die Ordinalzahl des {@link KritischerZustand}.
	 */
	private KritischerZustand(final String text, final int value) {
		m_text = text;
		m_value = value;
	}

	/**
	 * Liefert den Namen eines {@link KritischerZustand}.
	 * 
	 * @return der Names des {@link KritischerZustand}.
	 */
	public String getText() {
		return m_text;
	}

	/**
	 * Liefert die Ordinalzahl eines {@link KritischerZustand}.
	 * 
	 * @return die Ordinalzahl des {@link KritischerZustand}.
	 */
	public int getValue() {
		return m_value;
	}
}